# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.sources_api import SourcesApi


class TestSourcesApi(unittest.TestCase):
    """SourcesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SourcesApi()

    def tearDown(self) -> None:
        pass

    def test_sources_all_destroy(self) -> None:
        """Test case for sources_all_destroy

        """
        pass

    def test_sources_all_list(self) -> None:
        """Test case for sources_all_list

        """
        pass

    def test_sources_all_retrieve(self) -> None:
        """Test case for sources_all_retrieve

        """
        pass

    def test_sources_all_set_icon_create(self) -> None:
        """Test case for sources_all_set_icon_create

        """
        pass

    def test_sources_all_set_icon_url_create(self) -> None:
        """Test case for sources_all_set_icon_url_create

        """
        pass

    def test_sources_all_types_list(self) -> None:
        """Test case for sources_all_types_list

        """
        pass

    def test_sources_all_used_by_list(self) -> None:
        """Test case for sources_all_used_by_list

        """
        pass

    def test_sources_all_user_settings_list(self) -> None:
        """Test case for sources_all_user_settings_list

        """
        pass

    def test_sources_group_connections_all_destroy(self) -> None:
        """Test case for sources_group_connections_all_destroy

        """
        pass

    def test_sources_group_connections_all_list(self) -> None:
        """Test case for sources_group_connections_all_list

        """
        pass

    def test_sources_group_connections_all_partial_update(self) -> None:
        """Test case for sources_group_connections_all_partial_update

        """
        pass

    def test_sources_group_connections_all_retrieve(self) -> None:
        """Test case for sources_group_connections_all_retrieve

        """
        pass

    def test_sources_group_connections_all_update(self) -> None:
        """Test case for sources_group_connections_all_update

        """
        pass

    def test_sources_group_connections_all_used_by_list(self) -> None:
        """Test case for sources_group_connections_all_used_by_list

        """
        pass

    def test_sources_group_connections_kerberos_create(self) -> None:
        """Test case for sources_group_connections_kerberos_create

        """
        pass

    def test_sources_group_connections_kerberos_destroy(self) -> None:
        """Test case for sources_group_connections_kerberos_destroy

        """
        pass

    def test_sources_group_connections_kerberos_list(self) -> None:
        """Test case for sources_group_connections_kerberos_list

        """
        pass

    def test_sources_group_connections_kerberos_partial_update(self) -> None:
        """Test case for sources_group_connections_kerberos_partial_update

        """
        pass

    def test_sources_group_connections_kerberos_retrieve(self) -> None:
        """Test case for sources_group_connections_kerberos_retrieve

        """
        pass

    def test_sources_group_connections_kerberos_update(self) -> None:
        """Test case for sources_group_connections_kerberos_update

        """
        pass

    def test_sources_group_connections_kerberos_used_by_list(self) -> None:
        """Test case for sources_group_connections_kerberos_used_by_list

        """
        pass

    def test_sources_group_connections_ldap_create(self) -> None:
        """Test case for sources_group_connections_ldap_create

        """
        pass

    def test_sources_group_connections_ldap_destroy(self) -> None:
        """Test case for sources_group_connections_ldap_destroy

        """
        pass

    def test_sources_group_connections_ldap_list(self) -> None:
        """Test case for sources_group_connections_ldap_list

        """
        pass

    def test_sources_group_connections_ldap_partial_update(self) -> None:
        """Test case for sources_group_connections_ldap_partial_update

        """
        pass

    def test_sources_group_connections_ldap_retrieve(self) -> None:
        """Test case for sources_group_connections_ldap_retrieve

        """
        pass

    def test_sources_group_connections_ldap_update(self) -> None:
        """Test case for sources_group_connections_ldap_update

        """
        pass

    def test_sources_group_connections_ldap_used_by_list(self) -> None:
        """Test case for sources_group_connections_ldap_used_by_list

        """
        pass

    def test_sources_group_connections_oauth_create(self) -> None:
        """Test case for sources_group_connections_oauth_create

        """
        pass

    def test_sources_group_connections_oauth_destroy(self) -> None:
        """Test case for sources_group_connections_oauth_destroy

        """
        pass

    def test_sources_group_connections_oauth_list(self) -> None:
        """Test case for sources_group_connections_oauth_list

        """
        pass

    def test_sources_group_connections_oauth_partial_update(self) -> None:
        """Test case for sources_group_connections_oauth_partial_update

        """
        pass

    def test_sources_group_connections_oauth_retrieve(self) -> None:
        """Test case for sources_group_connections_oauth_retrieve

        """
        pass

    def test_sources_group_connections_oauth_update(self) -> None:
        """Test case for sources_group_connections_oauth_update

        """
        pass

    def test_sources_group_connections_oauth_used_by_list(self) -> None:
        """Test case for sources_group_connections_oauth_used_by_list

        """
        pass

    def test_sources_group_connections_plex_create(self) -> None:
        """Test case for sources_group_connections_plex_create

        """
        pass

    def test_sources_group_connections_plex_destroy(self) -> None:
        """Test case for sources_group_connections_plex_destroy

        """
        pass

    def test_sources_group_connections_plex_list(self) -> None:
        """Test case for sources_group_connections_plex_list

        """
        pass

    def test_sources_group_connections_plex_partial_update(self) -> None:
        """Test case for sources_group_connections_plex_partial_update

        """
        pass

    def test_sources_group_connections_plex_retrieve(self) -> None:
        """Test case for sources_group_connections_plex_retrieve

        """
        pass

    def test_sources_group_connections_plex_update(self) -> None:
        """Test case for sources_group_connections_plex_update

        """
        pass

    def test_sources_group_connections_plex_used_by_list(self) -> None:
        """Test case for sources_group_connections_plex_used_by_list

        """
        pass

    def test_sources_group_connections_saml_create(self) -> None:
        """Test case for sources_group_connections_saml_create

        """
        pass

    def test_sources_group_connections_saml_destroy(self) -> None:
        """Test case for sources_group_connections_saml_destroy

        """
        pass

    def test_sources_group_connections_saml_list(self) -> None:
        """Test case for sources_group_connections_saml_list

        """
        pass

    def test_sources_group_connections_saml_partial_update(self) -> None:
        """Test case for sources_group_connections_saml_partial_update

        """
        pass

    def test_sources_group_connections_saml_retrieve(self) -> None:
        """Test case for sources_group_connections_saml_retrieve

        """
        pass

    def test_sources_group_connections_saml_update(self) -> None:
        """Test case for sources_group_connections_saml_update

        """
        pass

    def test_sources_group_connections_saml_used_by_list(self) -> None:
        """Test case for sources_group_connections_saml_used_by_list

        """
        pass

    def test_sources_kerberos_create(self) -> None:
        """Test case for sources_kerberos_create

        """
        pass

    def test_sources_kerberos_destroy(self) -> None:
        """Test case for sources_kerberos_destroy

        """
        pass

    def test_sources_kerberos_list(self) -> None:
        """Test case for sources_kerberos_list

        """
        pass

    def test_sources_kerberos_partial_update(self) -> None:
        """Test case for sources_kerberos_partial_update

        """
        pass

    def test_sources_kerberos_retrieve(self) -> None:
        """Test case for sources_kerberos_retrieve

        """
        pass

    def test_sources_kerberos_sync_status_retrieve(self) -> None:
        """Test case for sources_kerberos_sync_status_retrieve

        """
        pass

    def test_sources_kerberos_update(self) -> None:
        """Test case for sources_kerberos_update

        """
        pass

    def test_sources_kerberos_used_by_list(self) -> None:
        """Test case for sources_kerberos_used_by_list

        """
        pass

    def test_sources_ldap_create(self) -> None:
        """Test case for sources_ldap_create

        """
        pass

    def test_sources_ldap_debug_retrieve(self) -> None:
        """Test case for sources_ldap_debug_retrieve

        """
        pass

    def test_sources_ldap_destroy(self) -> None:
        """Test case for sources_ldap_destroy

        """
        pass

    def test_sources_ldap_list(self) -> None:
        """Test case for sources_ldap_list

        """
        pass

    def test_sources_ldap_partial_update(self) -> None:
        """Test case for sources_ldap_partial_update

        """
        pass

    def test_sources_ldap_retrieve(self) -> None:
        """Test case for sources_ldap_retrieve

        """
        pass

    def test_sources_ldap_sync_status_retrieve(self) -> None:
        """Test case for sources_ldap_sync_status_retrieve

        """
        pass

    def test_sources_ldap_update(self) -> None:
        """Test case for sources_ldap_update

        """
        pass

    def test_sources_ldap_used_by_list(self) -> None:
        """Test case for sources_ldap_used_by_list

        """
        pass

    def test_sources_oauth_create(self) -> None:
        """Test case for sources_oauth_create

        """
        pass

    def test_sources_oauth_destroy(self) -> None:
        """Test case for sources_oauth_destroy

        """
        pass

    def test_sources_oauth_list(self) -> None:
        """Test case for sources_oauth_list

        """
        pass

    def test_sources_oauth_partial_update(self) -> None:
        """Test case for sources_oauth_partial_update

        """
        pass

    def test_sources_oauth_retrieve(self) -> None:
        """Test case for sources_oauth_retrieve

        """
        pass

    def test_sources_oauth_source_types_list(self) -> None:
        """Test case for sources_oauth_source_types_list

        """
        pass

    def test_sources_oauth_update(self) -> None:
        """Test case for sources_oauth_update

        """
        pass

    def test_sources_oauth_used_by_list(self) -> None:
        """Test case for sources_oauth_used_by_list

        """
        pass

    def test_sources_plex_create(self) -> None:
        """Test case for sources_plex_create

        """
        pass

    def test_sources_plex_destroy(self) -> None:
        """Test case for sources_plex_destroy

        """
        pass

    def test_sources_plex_list(self) -> None:
        """Test case for sources_plex_list

        """
        pass

    def test_sources_plex_partial_update(self) -> None:
        """Test case for sources_plex_partial_update

        """
        pass

    def test_sources_plex_redeem_token_authenticated_create(self) -> None:
        """Test case for sources_plex_redeem_token_authenticated_create

        """
        pass

    def test_sources_plex_redeem_token_create(self) -> None:
        """Test case for sources_plex_redeem_token_create

        """
        pass

    def test_sources_plex_retrieve(self) -> None:
        """Test case for sources_plex_retrieve

        """
        pass

    def test_sources_plex_update(self) -> None:
        """Test case for sources_plex_update

        """
        pass

    def test_sources_plex_used_by_list(self) -> None:
        """Test case for sources_plex_used_by_list

        """
        pass

    def test_sources_saml_create(self) -> None:
        """Test case for sources_saml_create

        """
        pass

    def test_sources_saml_destroy(self) -> None:
        """Test case for sources_saml_destroy

        """
        pass

    def test_sources_saml_list(self) -> None:
        """Test case for sources_saml_list

        """
        pass

    def test_sources_saml_metadata_retrieve(self) -> None:
        """Test case for sources_saml_metadata_retrieve

        """
        pass

    def test_sources_saml_partial_update(self) -> None:
        """Test case for sources_saml_partial_update

        """
        pass

    def test_sources_saml_retrieve(self) -> None:
        """Test case for sources_saml_retrieve

        """
        pass

    def test_sources_saml_update(self) -> None:
        """Test case for sources_saml_update

        """
        pass

    def test_sources_saml_used_by_list(self) -> None:
        """Test case for sources_saml_used_by_list

        """
        pass

    def test_sources_scim_create(self) -> None:
        """Test case for sources_scim_create

        """
        pass

    def test_sources_scim_destroy(self) -> None:
        """Test case for sources_scim_destroy

        """
        pass

    def test_sources_scim_groups_create(self) -> None:
        """Test case for sources_scim_groups_create

        """
        pass

    def test_sources_scim_groups_destroy(self) -> None:
        """Test case for sources_scim_groups_destroy

        """
        pass

    def test_sources_scim_groups_list(self) -> None:
        """Test case for sources_scim_groups_list

        """
        pass

    def test_sources_scim_groups_partial_update(self) -> None:
        """Test case for sources_scim_groups_partial_update

        """
        pass

    def test_sources_scim_groups_retrieve(self) -> None:
        """Test case for sources_scim_groups_retrieve

        """
        pass

    def test_sources_scim_groups_update(self) -> None:
        """Test case for sources_scim_groups_update

        """
        pass

    def test_sources_scim_groups_used_by_list(self) -> None:
        """Test case for sources_scim_groups_used_by_list

        """
        pass

    def test_sources_scim_list(self) -> None:
        """Test case for sources_scim_list

        """
        pass

    def test_sources_scim_partial_update(self) -> None:
        """Test case for sources_scim_partial_update

        """
        pass

    def test_sources_scim_retrieve(self) -> None:
        """Test case for sources_scim_retrieve

        """
        pass

    def test_sources_scim_update(self) -> None:
        """Test case for sources_scim_update

        """
        pass

    def test_sources_scim_used_by_list(self) -> None:
        """Test case for sources_scim_used_by_list

        """
        pass

    def test_sources_scim_users_create(self) -> None:
        """Test case for sources_scim_users_create

        """
        pass

    def test_sources_scim_users_destroy(self) -> None:
        """Test case for sources_scim_users_destroy

        """
        pass

    def test_sources_scim_users_list(self) -> None:
        """Test case for sources_scim_users_list

        """
        pass

    def test_sources_scim_users_partial_update(self) -> None:
        """Test case for sources_scim_users_partial_update

        """
        pass

    def test_sources_scim_users_retrieve(self) -> None:
        """Test case for sources_scim_users_retrieve

        """
        pass

    def test_sources_scim_users_update(self) -> None:
        """Test case for sources_scim_users_update

        """
        pass

    def test_sources_scim_users_used_by_list(self) -> None:
        """Test case for sources_scim_users_used_by_list

        """
        pass

    def test_sources_user_connections_all_destroy(self) -> None:
        """Test case for sources_user_connections_all_destroy

        """
        pass

    def test_sources_user_connections_all_list(self) -> None:
        """Test case for sources_user_connections_all_list

        """
        pass

    def test_sources_user_connections_all_partial_update(self) -> None:
        """Test case for sources_user_connections_all_partial_update

        """
        pass

    def test_sources_user_connections_all_retrieve(self) -> None:
        """Test case for sources_user_connections_all_retrieve

        """
        pass

    def test_sources_user_connections_all_update(self) -> None:
        """Test case for sources_user_connections_all_update

        """
        pass

    def test_sources_user_connections_all_used_by_list(self) -> None:
        """Test case for sources_user_connections_all_used_by_list

        """
        pass

    def test_sources_user_connections_kerberos_create(self) -> None:
        """Test case for sources_user_connections_kerberos_create

        """
        pass

    def test_sources_user_connections_kerberos_destroy(self) -> None:
        """Test case for sources_user_connections_kerberos_destroy

        """
        pass

    def test_sources_user_connections_kerberos_list(self) -> None:
        """Test case for sources_user_connections_kerberos_list

        """
        pass

    def test_sources_user_connections_kerberos_partial_update(self) -> None:
        """Test case for sources_user_connections_kerberos_partial_update

        """
        pass

    def test_sources_user_connections_kerberos_retrieve(self) -> None:
        """Test case for sources_user_connections_kerberos_retrieve

        """
        pass

    def test_sources_user_connections_kerberos_update(self) -> None:
        """Test case for sources_user_connections_kerberos_update

        """
        pass

    def test_sources_user_connections_kerberos_used_by_list(self) -> None:
        """Test case for sources_user_connections_kerberos_used_by_list

        """
        pass

    def test_sources_user_connections_ldap_create(self) -> None:
        """Test case for sources_user_connections_ldap_create

        """
        pass

    def test_sources_user_connections_ldap_destroy(self) -> None:
        """Test case for sources_user_connections_ldap_destroy

        """
        pass

    def test_sources_user_connections_ldap_list(self) -> None:
        """Test case for sources_user_connections_ldap_list

        """
        pass

    def test_sources_user_connections_ldap_partial_update(self) -> None:
        """Test case for sources_user_connections_ldap_partial_update

        """
        pass

    def test_sources_user_connections_ldap_retrieve(self) -> None:
        """Test case for sources_user_connections_ldap_retrieve

        """
        pass

    def test_sources_user_connections_ldap_update(self) -> None:
        """Test case for sources_user_connections_ldap_update

        """
        pass

    def test_sources_user_connections_ldap_used_by_list(self) -> None:
        """Test case for sources_user_connections_ldap_used_by_list

        """
        pass

    def test_sources_user_connections_oauth_create(self) -> None:
        """Test case for sources_user_connections_oauth_create

        """
        pass

    def test_sources_user_connections_oauth_destroy(self) -> None:
        """Test case for sources_user_connections_oauth_destroy

        """
        pass

    def test_sources_user_connections_oauth_list(self) -> None:
        """Test case for sources_user_connections_oauth_list

        """
        pass

    def test_sources_user_connections_oauth_partial_update(self) -> None:
        """Test case for sources_user_connections_oauth_partial_update

        """
        pass

    def test_sources_user_connections_oauth_retrieve(self) -> None:
        """Test case for sources_user_connections_oauth_retrieve

        """
        pass

    def test_sources_user_connections_oauth_update(self) -> None:
        """Test case for sources_user_connections_oauth_update

        """
        pass

    def test_sources_user_connections_oauth_used_by_list(self) -> None:
        """Test case for sources_user_connections_oauth_used_by_list

        """
        pass

    def test_sources_user_connections_plex_create(self) -> None:
        """Test case for sources_user_connections_plex_create

        """
        pass

    def test_sources_user_connections_plex_destroy(self) -> None:
        """Test case for sources_user_connections_plex_destroy

        """
        pass

    def test_sources_user_connections_plex_list(self) -> None:
        """Test case for sources_user_connections_plex_list

        """
        pass

    def test_sources_user_connections_plex_partial_update(self) -> None:
        """Test case for sources_user_connections_plex_partial_update

        """
        pass

    def test_sources_user_connections_plex_retrieve(self) -> None:
        """Test case for sources_user_connections_plex_retrieve

        """
        pass

    def test_sources_user_connections_plex_update(self) -> None:
        """Test case for sources_user_connections_plex_update

        """
        pass

    def test_sources_user_connections_plex_used_by_list(self) -> None:
        """Test case for sources_user_connections_plex_used_by_list

        """
        pass

    def test_sources_user_connections_saml_create(self) -> None:
        """Test case for sources_user_connections_saml_create

        """
        pass

    def test_sources_user_connections_saml_destroy(self) -> None:
        """Test case for sources_user_connections_saml_destroy

        """
        pass

    def test_sources_user_connections_saml_list(self) -> None:
        """Test case for sources_user_connections_saml_list

        """
        pass

    def test_sources_user_connections_saml_partial_update(self) -> None:
        """Test case for sources_user_connections_saml_partial_update

        """
        pass

    def test_sources_user_connections_saml_retrieve(self) -> None:
        """Test case for sources_user_connections_saml_retrieve

        """
        pass

    def test_sources_user_connections_saml_update(self) -> None:
        """Test case for sources_user_connections_saml_update

        """
        pass

    def test_sources_user_connections_saml_used_by_list(self) -> None:
        """Test case for sources_user_connections_saml_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
